#
# A simple example showing how to use IronPython with RedRat devices.
#
# IronPython (https://ironpython.net/) needs to be installed.
#
# To run: ipy IronPythonSample.py
#
import time
import clr

clr.AddReference("System.Xml")
import System
from System.IO import *
from System.Xml.Serialization import *

# Add ref to RedRat.dll. This is simply packages with the code, but you may want to check that it is 
# the most recent version.
clr.AddReferenceToFileAndPath(r"RedRat.dll")

# Import code from various RedRat namespaces.
import RedRat
from RedRat import *
from RedRat.Util import *
from RedRat.Util.Serialization import *
from RedRat.RedRat4.StreamIO.X import *
from RedRat.RedRat4.Usb.RedRatPico import *
from RedRat.AvDeviceDb import *

print('\nIronPython Sample Code\n======================\n')

# Find all known RR3s & RRXs.
locationInfoList = RRUtil.FindRedRats(
    LocationInfo.RedRatType.RedRat3 | 
    LocationInfo.RedRatType.RedRatX_USB |
    LocationInfo.RedRatType.RedRatPico)
if locationInfoList.Length == 0:
    print("No USB RedRat devices found.")
    exit()

# Take the first USB RR device found.
rrLi = locationInfoList[0]

if LocationInfo.IsRedRat3(rrLi.RRType):
    redrat = rrLi.GetRedRat();
    print("Have RedRat3 '{}'".format(rrLi.Name))
    connected = 0

elif LocationInfo.IsRedRatX(rrLi.RRType):
    redrat = RedRatX.GetInstance(rrLi);
    print("Have RedRatX '{}'".format(rrLi.Name))
    
    # Need to connect to RRX
    redrat.Connect()
    connected = 1

elif LocationInfo.IsRedRatPico(rrLi.RRType):
    redrat = RedRatPico.GetInstance(rrLi);
    print("Have RedRatPico '{}'".format(rrLi.Name))
    
    # Need to connect to RRX
    redrat.Connect()
    connected = 1

else:
    print("Can't handle this type of RedRat device.")
    exit()

# Print out some information
print("\nRedRat Info:")

# Physical position is returned in LocationInfo object
print("\tLocation:\t\t{}".format(redrat.LocationInformation))

# Physical USB hardware information
devInfo = redrat.DeviceInformation;
print("\tHardware Version:\t{}.{}".format(devInfo.ProductName, devInfo.ProductDescriptor.Version))
print("\tSerial Number:\t\t{}".format(devInfo.SerialNumber))

# Firmware version information read directly from RedRat
print("\tFirmware Version:\t{}\n".format(redrat.FirmwareVersion))

# Blink the visible LED
redrat.Blink()
print("BLINK!")
time.sleep(1)

# Load an IR signal database file
filename = r"..\dependencies\DeviceDB.xml"
avDeviceDB = Serializer.AvDeviceDbFromXmlFile(filename).Object

# Get the IR signal SKY+ -> Play
sig = avDeviceDB.GetIRPacket("SKY+", "Play")
if sig == None:
    print("Signal not found in the DB.")
    exit()

# Output the IR signal.
redrat.OutputModulatedSignal(sig)
print("OUTPUT IR SIGNAL.")

# Tidy up and close
if connected:
    redrat.Disconnect()

RRUtil.DisposeOfAllRedRats()
